@@ -1,15 +1,19 @@
 """LiveLLM Client - Python client for the LiveLLM Proxy and Realtime APIs."""
 
-from .livellm import LivellmClient
+from .livellm import LivellmClient, LivellmWsClient, BaseLivellmClient
+from .transcripton import TranscriptionWsClient
 from . import models
 
-__version__ = "1.1.0"
+__version__ = "1.2.0"
 
 __all__ = [    
     # Version
     "__version__",
     # Classes
     "LivellmClient",
+    "LivellmWsClient",
+    "BaseLivellmClient",
+    "TranscriptionWsClient",
     # Models
     *models.__all__,
 ]
