@@ -1,4 +1,4 @@
-from pydantic import BaseModel, Field
+from pydantic import BaseModel, Field, model_validator
 from typing import List
 from .common import BaseRequest
 from .audio.speak import SpeakRequest
@@ -6,7 +6,7 @@ from .audio.transcribe import TranscribeRequest
 from .agent.agent import AgentRequest
 from enum import Enum
 
-class FallbackStrategy(Enum):
+class FallbackStrategy(str, Enum):
     SEQUENTIAL = "sequential"
     PARALLEL = "parallel"
     
@@ -14,7 +14,7 @@ class FallbackRequest(BaseModel):
     requests: List[BaseRequest] = Field(..., description="List of requests to try as fallbacks")
     strategy: FallbackStrategy = Field(FallbackStrategy.SEQUENTIAL, description="The strategy to use for fallback")
     timeout_per_request: int = Field(default=360, description="The timeout to use for each request")
-
+    
 class AgentFallbackRequest(FallbackRequest):
     requests: List[AgentRequest] = Field(..., description="List of agent requests to try as fallbacks")
 
